@@ -526,10 +526,14 @@ class AWSCloudFormation(AWSSession):
         if 'stack_name' in kwargs:
             stack_name = kwargs.get('stack_name')
 
+        change_set_type = 'UPDATE'
+        if kwargs.get('new_stack', False):
+            change_set_type = 'CREATE'
+
         template_url = "https://s3.amazonaws.com/%s/%s" % (
             self.s3_bucket, self.s3_key)
 
-        change_set_name = 'cs-{ts}'.format(ts=time.strftime('%Y-%m-%d_%H-%M-%S'))
+        change_set_name = 'cs-{ts}'.format(ts=time.strftime('%Y-%m-%d-%H-%M-%S'))
         client_token = 'token{uuid}'.format(uuid=uuid.uuid4())
 
         print("Running dry_run for stack {}".format(stack_name))
@@ -537,7 +541,7 @@ class AWSCloudFormation(AWSSession):
             StackName=stack_name,
             ChangeSetName=change_set_name,
             ClientToken=client_token,
-            ChangeSetType='UPDATE',
+            ChangeSetType=change_set_type,
             TemplateURL=template_url,
             Capabilities=['CAPABILITY_NAMED_IAM'],
             Parameters=self._join_parameters(
